pub enum AuthLookup {
    Empty,
    Records {
        answers: LookupRecords,
        additionals: Option<LookupRecords>,
    },
    SOA(LookupRecords),
    AXFR {
        start_soa: LookupRecords,
        records: LookupRecords,
        end_soa: LookupRecords,
    },
}
The result of a lookup on an Authority

Lifetimes

  • 'c - the catalogue lifetime
  • 'r - the recordset lifetime, subset of ’c
  • 'q - the queries lifetime

Variants



Empty

No records



Records

Fields

answers: LookupRecords

Authoritative answers

additionals: Option<LookupRecords>

Optional set of LookupRecords

Records



SOA(LookupRecords)

Soa only differs from Records in that the lifetime on the name is from the authority, and not the query



AXFR

Fields

start_soa: LookupRecords

The first SOA record in an AXFR response

records: LookupRecords

The records to return

end_soa: LookupRecords

The last SOA record of an AXFR (matches the first)

An axfr starts with soa, chained to all the records, then another soa…

Implementations

source

impl AuthLookup

source

pub fn answers( answers: LookupRecords, additionals: Option<LookupRecords> ) -> Self

Construct an answer with additional section

source

pub fn is_empty(&self) -> bool

Returns true if either the associated Records are empty, or this is a NameExists or NxDomain

source

pub fn was_empty(&self) -> bool

This is an NxDomain or NameExists, and has no associated records

this consumes the iterator, and verifies it is empty

source

pub fn iter(&self) -> AuthLookupIter<'_>

Conversion to an iterator

source

pub fn unwrap_records(self) -> LookupRecords

Does not panic, but will return no records if it is not of that type

source

pub fn take_additionals(&mut self) -> Option<LookupRecords>

Takes the additional records, leaving behind None