pub struct LookupOptions { /* private fields */ }
LookupOptions that specify different options from the client to include or exclude various records in the response.

For example, is_dnssec will include RRSIG in the response, supported_algorithms will only include a subset of RRSIG based on the algorithms supported by the request.

Implementations

source

impl LookupOptions

Lookup Options for the request to the authority

source

pub fn for_dnssec( is_dnssec: bool, supported_algorithms: SupportedAlgorithms ) -> Self

Available on crate feature dnssec only.

Return a new LookupOptions

source

pub fn set_is_dnssec(self, val: bool) -> Self

Specify that this lookup should return DNSSEC related records as well, e.g. RRSIG

source

pub fn is_dnssec(&self) -> bool

If true this lookup should return DNSSEC related records as well, e.g. RRSIG

source

pub fn set_supported_algorithms(self, val: SupportedAlgorithms) -> Self

Available on crate feature dnssec only.

Specify the algorithms for which DNSSEC records should be returned

source

pub fn supported_algorithms(&self) -> SupportedAlgorithms

Available on crate feature dnssec only.

The algorithms for which DNSSEC records should be returned

source

pub fn rrset_with_supported_algorithms<'r>( &self, record_set: &'r RecordSet ) -> RrsetRecords<'r>

Returns the subset of the rrset limited to the supported_algorithms