pub struct Queries { /* private fields */ }
A set of Queries with the associated serialized data

Implementations

source

impl Queries

source

pub fn read( decoder: &mut BinDecoder<'_>, num_queries: usize ) -> ProtoResult<Self>

Read queries from a decoder

source

pub fn len(&self) -> usize

return the number of queries in the request

source

pub fn is_empty(&self) -> bool

Returns true if there are no queries

source

pub fn as_bytes(&self) -> &[u8]

returns the bytes as they were seen from the Client