Module hickory_server::error

source ·
All defined errors for Hickory DNS

Structs

  • The error type for errors that get returned in the crate
  • The error type for errors that get returned in the crate

Enums

Type Aliases