Server component for hosting a domain name servers operations.
Structs
- Request
- An incoming request to the DNS catalog
- Request
Info - A narrow view of the Request, specifically a verified single query for the request
- Response
Handle - A handler for wrapping a
BufDnsStreamHandle, which will properly serialize the message and add the associated destination. - Response
Info - Information about the response sent for a request
- Server
- A Futures based implementation of a DNS server
- Timeout
Stream - This wraps the underlying Stream in a timeout.
Traits
- Request
Handler - Trait for handling incoming requests, and providing a message response.
- Response
Handler - A handler for send a response to a client
Functions
- default_
tls_ server_ config __tls - Construct a default
ServerConfigfor the given ALPN protocol and server cert resolver.