pub struct Request { /* private fields */ }Expand description
An incoming request to the DNS catalog
Implementations
Sourceimpl Request
impl Request
Sourcepub fn from_bytes(
raw: Vec<u8>,
src: SocketAddr,
protocol: Protocol,
) -> Result<Self, ProtoError>
pub fn from_bytes( raw: Vec<u8>, src: SocketAddr, protocol: Protocol, ) -> Result<Self, ProtoError>
Construct a new Request from the raw bytes, source address, and protocol
Sourcepub fn from_message(
message: MessageRequest,
src: SocketAddr,
protocol: Protocol,
) -> Result<Self, ProtoError>
Available on crate feature testing only.
pub fn from_message( message: MessageRequest, src: SocketAddr, protocol: Protocol, ) -> Result<Self, ProtoError>
testing only.Construct a new Request from the encoding of a MessageRequest, source address, and protocol
Sourcepub fn request_info(&self) -> Result<RequestInfo<'_>, LookupError>
pub fn request_info(&self) -> Result<RequestInfo<'_>, LookupError>
Return just the header and request information from the Request Message
Returns an error if there is not exactly one query
Sourcepub fn src(&self) -> SocketAddr
pub fn src(&self) -> SocketAddr
The IP address from which the request originated.
Methods from Deref<Target = MessageRequest>