#[non_exhaustive]pub struct RequestInfo<'a> {
pub src: SocketAddr,
pub protocol: Protocol,
pub metadata: &'a Metadata,
pub query: &'a LowerQuery,
}Expand description
A narrow view of the Request, specifically a verified single query for the request
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.src: SocketAddrThe source address from which the request came
protocol: ProtocolThe protocol used for the request
metadata: &'a MetadataThe header from the original request
query: &'a LowerQueryThe query from the request
Implementations
Sourceimpl<'a> RequestInfo<'a>
impl<'a> RequestInfo<'a>
Sourcepub fn new(
src: SocketAddr,
protocol: Protocol,
metadata: &'a Metadata,
query: &'a LowerQuery,
) -> Self
pub fn new( src: SocketAddr, protocol: Protocol, metadata: &'a Metadata, query: &'a LowerQuery, ) -> Self
Construct a new RequestInfo
Arguments
src- The source address from which the request cameprotocol- The protocol used for the requestheader- The header from the original requestquery- The query from the request, LowerQuery is intended to reduce complexity for lookups in zone handlers