ForwardZoneHandlerBuilder

Struct ForwardZoneHandlerBuilder 

pub struct ForwardZoneHandlerBuilder<P: ConnectionProvider> { /* private fields */ }
Available on crate feature resolver only.
A builder to construct a ForwardZoneHandler.

Created by ForwardZoneHandler::builder.

Implementations

Source

impl<P: ConnectionProvider> ForwardZoneHandlerBuilder<P>

pub fn with_origin(self, origin: Name) -> Self

Set the origin of the zone handler.

pub fn with_trust_anchor(self, trust_anchor: Arc<TrustAnchors>) -> Self

Available on crate feature __dnssec only.

Enables DNSSEC validation, and sets the DNSSEC trust anchors to be used by the forward zone handler.

This overrides the trust anchor path in the ResolverOpts.

pub fn options_mut(&mut self) -> &mut ResolverOpts

Returns a mutable reference to the ResolverOpts.

pub fn with_domain(self, domain: Name) -> Self

Set the system domain name.

Set the search domains.

pub fn build(self) -> Result<ForwardZoneHandler<P>, String>

Construct the zone handler.