InMemoryZoneHandler

Struct InMemoryZoneHandler 

pub struct InMemoryZoneHandler<P = TokioRuntimeProvider> { /* private fields */ }
InMemoryZoneHandler is responsible for storing the resource records for a particular zone.

Zone handlers default to DNSClass IN. The ZoneType specifies if this should be treated as the start of authority for the zone, is a Secondary, or a cached zone.

Implementations

Source

impl<P: RuntimeProvider + Send + Sync> InMemoryZoneHandler<P>

pub fn new( origin: Name, records: BTreeMap<RrKey, RecordSet>, zone_type: ZoneType, axfr_policy: AxfrPolicy, nx_proof_kind: Option<NxProofKind>, ) -> Result<Self, String>

Creates a new ZoneHandler.

Arguments
  • origin - The zone Name being created, this should match that of the RecordType::SOA record.
  • records - The map of the initial set of records in the zone.
  • zone_type - The type of zone, i.e. is this authoritative?
  • axfr_policy - A policy for determining if AXFR is allowed.
  • nx_proof_kind - The kind of non-existence proof to be used by the server.
Return value

The new ZoneHandler.

pub fn empty( origin: Name, zone_type: ZoneType, axfr_policy: AxfrPolicy, nx_proof_kind: Option<NxProofKind>, ) -> Self

Creates an empty ZoneHandler

Warning

This is an invalid zone, SOA must be added

pub fn class(&self) -> DNSClass

The DNSClass of this zone

pub fn set_axfr_policy(&mut self, policy: AxfrPolicy)

Available on crate features testing only.

Set the AXFR policy for testing purposes

pub fn clear(&mut self)

Clears all records (including SOA, etc)

pub async fn secure_keys(&self) -> impl Deref<Target = [DnssecSigner]> + '_

Available on crate features __dnssec and testing only.

Retrieve the Signer, which contains the private keys, for this zone

pub async fn records( &self, ) -> impl Deref<Target = BTreeMap<RrKey, Arc<RecordSet>>> + '_

Get all the records

pub async fn records_mut( &self, ) -> impl DerefMut<Target = BTreeMap<RrKey, Arc<RecordSet>>> + '_

Get a mutable reference to the records

pub fn records_get_mut(&mut self) -> &mut BTreeMap<RrKey, Arc<RecordSet>>

Get a mutable reference to the records

pub async fn minimum_ttl(&self) -> u32

Returns the minimum ttl (as used in the SOA record)

pub async fn serial(&self) -> u32

get the current serial number for the zone.

pub async fn upsert(&self, record: Record, serial: u32) -> bool

Inserts or updates a Record depending on its existence in the zone.

Guarantees that SOA, CNAME only has one record, will implicitly update if they already exist.

Arguments
  • record - The Record to be inserted or updated.
  • serial - Current serial number to be recorded against updates.
Return value

true if the value was inserted, false otherwise

pub fn upsert_mut(&mut self, record: Record, serial: u32) -> bool

Non-async version of upsert when behind a mutable reference.

pub fn add_zone_signing_key_mut( &mut self, signer: DnssecSigner, ) -> DnsSecResult<()>

Available on crate feature __dnssec only.

Non-async method of add_zone_signing_key when behind a mutable reference

pub fn secure_zone_mut(&mut self) -> DnsSecResult<()>

Available on crate feature __dnssec only.

(Re)generates the nsec records, increments the serial number and signs the zone