pub struct RecursiveAuthority { /* private fields */ }
An authority that will forward resolutions to upstream resolvers.

This uses the hickory-resolver for resolving requests.

Implementations

source

impl RecursiveAuthority

source

pub async fn try_from_config( origin: Name, _zone_type: ZoneType, config: &RecursiveConfig, root_dir: Option<&Path> ) -> Result<Self, String>

Read the Authority for the origin from the specified configuration