Module persistence

Module persistence 

Available on crate feature sqlite only.
All zone persistence related types

Structs

Journal
The Journal is the audit log of all changes to a zone after initial creation.
JournalIter
Returns an iterator over all items in a Journal

Enums

PersistenceError
The error kind for errors that get returned in the crate

Constants

CURRENT_VERSION
The current Journal version of the application