TsigKeyConfig

Struct TsigKeyConfig 

pub struct TsigKeyConfig {
    pub name: String,
    pub key_file: PathBuf,
    pub algorithm: TsigAlgorithm,
    pub fudge: u16,
}
Available on crate features sqlite and __dnssec only.
Configuration for a TSIG authentication signer key

Fields

name: String

The key name

key_file: PathBuf

A path to the unencoded symmetric HMAC key data

algorithm: TsigAlgorithm

The key algorithm

fudge: u16

Allowed +/- difference (in seconds) between the time a TSIG request was signed and when it is verified.

A fudge value that is too large may leave the server open to replay attacks. A fudge value that is too small may cause failures from latency and clock desynchronization.

RFC 8945 recommends a fudge value of 300 seconds (the default if not specified).