Module zone_handler

Module zone_handler 

Module for Catalog of ZoneHandler zones which are responsible for storing RRSet records.

Structs

AxfrRecords
A collection of RecordSets for an AXFR.
AxfrRecordsIter
An iterator over all records in a zone, except the SOA record.
Catalog
Set of zones and zone handlers available to this server.
LookupOptions
Options from the client to include or exclude various records in the response.
MessageRequest
A Message which captures the data from an inbound request
MessageResponse
A crate::proto::serialize::binary::BinEncodable message with borrowed data for Responses in the Server
MessageResponseBuilder
A builder for MessageResponses
Nsec3QueryInfo__dnssec
Information required to compute the NSEC3 records that should be sent for a query.
Queries
A set of Queries with the associated serialized data
ZoneTransfer
A copy of all data in a zone.

Enums

AuthLookup
The result of a lookup on a ZoneHandler
AuthLookupIter
An iterator over a ZoneHandler lookup
AxfrPolicy
AxfrPolicy describes how to handle AXFR requests
LookupControlFlow
Result of a Lookup in the Catalog and ZoneHandler
LookupError
A query could not be fulfilled
LookupRecords
The result of a lookup
LookupRecordsIter
Iterator over lookup records
ZoneType
The type of zone stored in a Catalog

Traits

DnssecZoneHandler
Extension to ZoneHandler to allow for DNSSEC features
UpdateRequest
A type which represents an MessageRequest for dynamic Update.
ZoneHandler
ZoneHandler implementations can be used with a Catalog