#[non_exhaustive]pub enum AuthLookup {
Empty,
Records {
answers: LookupRecords,
additionals: Option<LookupRecords>,
},
Resolved(Lookup),
Response(Message),
}Expand description
The result of a lookup on a ZoneHandler
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Empty
No records
Records
Records
Fields

answers: LookupRecordsAuthoritative answers

additionals: Option<LookupRecords>Optional set of LookupRecords
Resolved(Lookup)
Available on crate feature
resolver only.Records resulting from a resolver lookup
Response(Message)
A response message
Implementations
Sourceimpl AuthLookup
impl AuthLookup
Sourcepub fn answers(
answers: LookupRecords,
additionals: Option<LookupRecords>,
) -> Self
pub fn answers( answers: LookupRecords, additionals: Option<LookupRecords>, ) -> Self
Construct an answer with additional section
Sourcepub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool
Returns true if either the associated Records are empty, or this is a NameExists or NxDomain
Sourcepub fn was_empty(&self) -> bool
pub fn was_empty(&self) -> bool
This is an NxDomain or NameExists, and has no associated records
this consumes the iterator, and verifies it is empty
Sourcepub fn iter(&self) -> AuthLookupIter<'_> ⓘ
pub fn iter(&self) -> AuthLookupIter<'_> ⓘ
Conversion to an iterator
Sourcepub fn unwrap_records(self) -> LookupRecords
pub fn unwrap_records(self) -> LookupRecords
Does not panic, but will return no records if it is not of that type
Iterates over the records from the Authority section, if present.
Sourcepub fn additionals(&self) -> Option<LookupRecordsIter<'_>>
pub fn additionals(&self) -> Option<LookupRecordsIter<'_>>
Iterates over the records from the Additional section, if present.
Sourcepub fn take_additionals(&mut self) -> Option<LookupRecords>
pub fn take_additionals(&mut self) -> Option<LookupRecords>
Takes the additional records, leaving behind None