LookupControlFlow

Enum LookupControlFlow 

pub enum LookupControlFlow<T, E = LookupError> {
    Continue(Result<T, E>),
    Break(Result<T, E>),
    Skip,
}
Result of a Lookup in the Catalog and ZoneHandler

  • All zone handlers should default to using LookupControlFlow::Continue to wrap their responses. These responses may be passed to other zone handlers for analysis or requery purposes.
  • Zone handlers may use LookupControlFlow::Break to indicate the response must be returned immediately to the client, without consulting any other zone handlers. For example, if the user configures a blocklist zone handler, it would not be appropriate to pass the query to any additional zone handlers to try to resolve, as that might be used to leak information to a hostile party, and so a blocklist (or similar) zone handler should wrap responses for any blocklist hits in LookupControlFlow::Break.
  • Zone handlers may use LookupControlFlow::Skip to indicate the zone handler did not attempt to process a particular query. This might be used, for example, in a block list zone handler for any queries that did not match the blocklist, to allow the recursor or forwarder to resolve the query. Skip must not be used to represent an empty lookup; (use Continue(EmptyLookup) or Break(EmptyLookup) for that.)

Variants



Continue(Result<T, E>)

A lookup response that may be passed to one or more additional zone handlers before being returned to the client.



Break(Result<T, E>)

A lookup response that must be immediately returned to the client without consulting any other zone handlers.



Skip

The zone handler did not answer the query and the next zone handler in the chain should be consulted.

Implementations

Source

impl<T, E> LookupControlFlow<T, E>

The following are a minimal set of methods typically used with Result or Option, and that were used in the server code or test suite prior to when the LookupControlFlow type was created (zone handler lookup functions previously returned a Result over a Lookup or LookupError type.)

pub fn is_continue(&self) -> bool

Return true if self is LookupControlFlow::Continue

pub fn is_break(&self) -> bool

Return true if self is LookupControlFlow::Break

pub fn map_result(self) -> Option<Result<T, E>>

Maps inner Ok(T) and Err(E) to Some(Result<T,E>) and Skip to None

Source

impl<E: Display> LookupControlFlow<AuthLookup, E>

pub fn expect(self, msg: &str) -> AuthLookup

Return inner Ok variant or panic with a custom error message.

pub fn expect_err(self, msg: &str) -> E

Return inner Err variant or panic with a custom error message.

pub fn unwrap(self) -> AuthLookup

Return inner Ok variant or panic

pub fn unwrap_err(self) -> E

Return inner Err variant or panic

pub fn unwrap_or_default(self) -> AuthLookup

Return inner Ok Variant or default value

pub fn map<U, F: FnOnce(AuthLookup) -> U>( self, op: F, ) -> LookupControlFlow<U, E>

Maps inner Ok(T) to Ok(U), passing inner Err and Skip values unchanged.

pub fn map_err<U, F: FnOnce(E) -> U>( self, op: F, ) -> LookupControlFlow<AuthLookup, U>

Maps inner Err(T) to Err(U), passing Ok and Skip values unchanged.