#[non_exhaustive]pub enum LookupError {
BadQueryCount(usize),
NameExists,
ResponseCode(ResponseCode),
NetError(NetError),
RecursiveError(RecursorError),
Io(Error),
}Expand description
A query could not be fulfilled
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
BadQueryCount(usize)
The query had an invalid number of queries
NameExists
A record at the same Name as the query exists, but not of the queried RecordType
ResponseCode(ResponseCode)
There was an error performing the lookup
NetError(NetError)
Proto error
RecursiveError(RecursorError)
Available on crate feature
recursor only.Recursive Resolver Error
Io(Error)
An underlying IO error occurred
Implementations
Sourceimpl LookupError
impl LookupError
Sourcepub fn for_name_exists() -> Self
pub fn for_name_exists() -> Self
Create a lookup error, specifying that a name exists at the location, but no matching RecordType
Sourcepub fn is_nx_domain(&self) -> bool
pub fn is_nx_domain(&self) -> bool
This is a non-existent domain name
Sourcepub fn is_no_records_found(&self) -> bool
pub fn is_no_records_found(&self) -> bool
Returns true if no records were returned
Sourcepub fn into_soa(self) -> Option<Box<Record<SOA>>>
pub fn into_soa(self) -> Option<Box<Record<SOA>>>
Returns the SOA record, if the error contains one
Return authority records