pub struct Queries { /* private fields */ }Expand description
A set of Queries with the associated serialized data
Implementations
Sourceimpl Queries
impl Queries
Sourcepub fn new(query: Vec<LowerQuery>) -> Self
Available on crate features testing only.
pub fn new(query: Vec<LowerQuery>) -> Self
testing only.Construct a mock Queries object for a given query for testing purposes
Sourcepub fn read(
decoder: &mut BinDecoder<'_>,
num_queries: usize,
) -> Result<Self, DecodeError>
pub fn read( decoder: &mut BinDecoder<'_>, num_queries: usize, ) -> Result<Self, DecodeError>
Read queries from a decoder
Sourcepub fn queries(&self) -> &[LowerQuery]
pub fn queries(&self) -> &[LowerQuery]
Returns the queries from the request