pub struct ZoneTransfer {
pub start_soa: LookupRecords,
pub records: AxfrRecords,
pub end_soa: LookupRecords,
}Expand description
A copy of all data in a zone.
This is used in the AXFR sub-protocol.
Fields
start_soa: LookupRecordsThe SOA record, plus its RRSIG.
This is sent at the start of the first message of the response.
records: AxfrRecordsAll the records in the zone.
end_soa: LookupRecordsThe SOA record again.
This is sent at the end of the last message of the response.
Implementations