ResponseHandler

Trait ResponseHandler 

pub trait ResponseHandler:
    Clone
    + Send
    + Sync
    + Unpin
    + 'static {
    // Required method
    fn send_response<'a, 'life0, 'life1, 'async_trait>(
        &'life0 mut self,
        response: MessageResponse<'life1, 'a, impl 'async_trait + Iterator<Item = &'a Record> + Send + 'a, impl 'async_trait + Iterator<Item = &'a Record> + Send + 'a, impl 'async_trait + Iterator<Item = &'a Record> + Send + 'a, impl 'async_trait + Iterator<Item = &'a Record> + Send + 'a>,
    ) -> Pin<Box<dyn Future<Output = Result<ResponseInfo, NetError>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'a: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait;
}
A handler for send a response to a client

Required Methods

fn send_response<'a, 'life0, 'life1, 'async_trait>( &'life0 mut self, response: MessageResponse<'life1, 'a, impl 'async_trait + Iterator<Item = &'a Record> + Send + 'a, impl 'async_trait + Iterator<Item = &'a Record> + Send + 'a, impl 'async_trait + Iterator<Item = &'a Record> + Send + 'a, impl 'async_trait + Iterator<Item = &'a Record> + Send + 'a>, ) -> Pin<Box<dyn Future<Output = Result<ResponseInfo, NetError>> + Send + 'async_trait>>
where Self: 'async_trait, 'a: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

Serializes and sends a message to the wrapped handle

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors