pub struct BlocklistZoneHandler { /* private fields */ }blocklist only.Expand description
A conditional zone handler that will resolve queries against one or more block lists and return a forged response. The typical use case will be to use this in a chained configuration before a forwarding or recursive resolver in order to pre-emptively block queries for hosts that are on a block list. Refer to tests/test-data/test_configs/chained_blocklist.toml for an example of this configuration.
The blocklist zone handler also supports the consult interface, which allows a zone handler to review a query/response that has been processed by another zone handler, and, optionally, overwrite that response before returning it to the requestor. There is an example of this configuration in tests/test-data/test_configs/example_consulting_blocklist.toml. The main intended use of this feature is to allow log-only configurations, to allow administrators to see if blocklist domains are being queried. While this can be configured to overwrite responses, it is not recommended to do so - it is both more efficient, and more secure, to allow the blocklist to drop queries pre-emptively, as in the first example.
Implementations
Sourceimpl BlocklistZoneHandler
impl BlocklistZoneHandler
Sourcepub fn try_from_config(
origin: Name,
config: BlocklistConfig,
base_dir: Option<&Path>,
) -> Result<Self, String>
pub fn try_from_config( origin: Name, config: BlocklistConfig, base_dir: Option<&Path>, ) -> Result<Self, String>
Read the ZoneHandler for the origin from the specified configuration
Sourcepub fn add(&mut self, handle: impl Read) -> Result<(), Error>
pub fn add(&mut self, handle: impl Read) -> Result<(), Error>
Add the contents of a block list to the in-memory cache. This function is normally called from try_from_config, but it can be invoked after the blocklist zone handler is created.
Arguments
handle- A source implementingstd::io::Readthat contains the blocklist entries to insert into the in-memory cache.
Return value
Result<(), std::io::Error>
Expected format of blocklist entries
- One entry per line
- Any character after a ‘#’ will be treated as a comment and stripped out.
- Leading wildcard entries are supported when the user has wildcard_match set to true. E.g., ‘*.foo.com’ will match any host in the foo.com domain. Intermediate wildcard matches, such as ‘www.*.com’ are not supported. Note: when wildcard matching is enabled, min_wildcard_depth (default: 2) controls how many static name labels must be present for a wildcard entry to be valid. With the default value of 2, an entry for ‘*.foo.com’ would be accepted, but an entry for ‘*.com’ would not.
- All entries are treated as being fully-qualified. If an entry does not contain a trailing ‘.’, one will be added before insertion into the cache.
Example
use std::{fs::File, net::{Ipv4Addr, Ipv6Addr}, path::Path, str::FromStr, sync::Arc};
use hickory_proto::rr::{LowerName, RecordType, Name};
use hickory_server::{
store::blocklist::*,
zone_handler::{LookupControlFlow, LookupOptions, ZoneHandler, ZoneType},
};
#[tokio::main]
async fn main() {
let config = BlocklistConfig {
wildcard_match: true,
min_wildcard_depth: 2,
lists: vec!["default/blocklist.txt".to_string()],
sinkhole_ipv4: None,
sinkhole_ipv6: None,
block_message: None,
ttl: 86_400,
consult_action: BlocklistConsultAction::Disabled,
log_clients: true,
};
let mut blocklist = BlocklistZoneHandler::try_from_config(
Name::root(),
config,
Some(Path::new("../../tests/test-data/test_configs")),
).unwrap();
let handle = File::open("../../tests/test-data/test_configs/default/blocklist2.txt").unwrap();
if let Err(e) = blocklist.add(handle) {
panic!("error adding blocklist: {e:?}");
}
let origin = blocklist.origin().clone();
let handler = Arc::new(blocklist) as Arc<dyn ZoneHandler>;
// In this example, malc0de.com only exists in the blocklist2.txt file we added to the
// zone handler after instantiating it. The following simulates a lookup against the
// blocklist zone handler, and checks for the expected response for a blocklist match.
use LookupControlFlow::*;
let Break(Ok(_res)) = handler.lookup(
&LowerName::from(Name::from_ascii("malc0de.com.").unwrap()),
RecordType::A,
None,
LookupOptions::default(),
).await else {
panic!("blocklist zone handler did not return expected match");
};
}Sourcepub fn entry_count(&self) -> usize
pub fn entry_count(&self) -> usize
Number of unique blocklist entries currently loaded in memory.