pub struct FileZoneHandler { /* private fields */ }Expand description
FileZoneHandler is responsible for storing the resource records for a particular zone.
Zone handlers default to DNSClass IN. The ZoneType specifies if this should be treated as the start of authority for the zone, is a Secondary, or a cached zone.
Implementations
Sourceimpl FileZoneHandler
impl FileZoneHandler
Sourcepub async fn new(in_memory: InMemoryZoneHandler) -> Self
pub async fn new(in_memory: InMemoryZoneHandler) -> Self
Creates a new ZoneHandler.
Arguments
origin- The zoneNamebeing created, this should match that of theRecordType::SOArecord.records- The map of the initial set of records in the zone.zone_type- The type of zone, i.e. is this authoritative?axfr_policy- A policy for determining if AXFR is allowed.nx_proof_kind- The kind of non-existence proof to be used by the server.
Return value
The new ZoneHandler.
Sourcepub fn try_from_config(
origin: Name,
zone_type: ZoneType,
axfr_policy: AxfrPolicy,
root_dir: Option<&Path>,
config: &FileConfig,
nx_proof_kind: Option<NxProofKind>,
) -> Result<Self, String>
pub fn try_from_config( origin: Name, zone_type: ZoneType, axfr_policy: AxfrPolicy, root_dir: Option<&Path>, config: &FileConfig, nx_proof_kind: Option<NxProofKind>, ) -> Result<Self, String>
Read the ZoneHandler for the origin from the specified configuration
Methods from Deref<Target = InMemoryZoneHandler>
Sourcepub fn set_axfr_policy(&mut self, policy: AxfrPolicy)
Available on crate features testing only.
pub fn set_axfr_policy(&mut self, policy: AxfrPolicy)
testing only.Set the AXFR policy for testing purposes
Sourcepub async fn secure_keys(&self) -> impl Deref<Target = [DnssecSigner]> + '_
Available on crate features __dnssec and testing only.
pub async fn secure_keys(&self) -> impl Deref<Target = [DnssecSigner]> + '_
__dnssec and testing only.Retrieve the Signer, which contains the private keys, for this zone
Sourcepub async fn records(
&self,
) -> impl Deref<Target = BTreeMap<RrKey, Arc<RecordSet>>> + '_
pub async fn records( &self, ) -> impl Deref<Target = BTreeMap<RrKey, Arc<RecordSet>>> + '_
Get all the records
Sourcepub async fn records_mut(
&self,
) -> impl DerefMut<Target = BTreeMap<RrKey, Arc<RecordSet>>> + '_
pub async fn records_mut( &self, ) -> impl DerefMut<Target = BTreeMap<RrKey, Arc<RecordSet>>> + '_
Get a mutable reference to the records
Sourcepub fn records_get_mut(&mut self) -> &mut BTreeMap<RrKey, Arc<RecordSet>>
pub fn records_get_mut(&mut self) -> &mut BTreeMap<RrKey, Arc<RecordSet>>
Get a mutable reference to the records
Sourcepub async fn minimum_ttl(&self) -> u32
pub async fn minimum_ttl(&self) -> u32
Returns the minimum ttl (as used in the SOA record)
Sourcepub async fn upsert(&self, record: Record, serial: u32) -> bool
pub async fn upsert(&self, record: Record, serial: u32) -> bool
Inserts or updates a Record depending on its existence in the zone.
Guarantees that SOA, CNAME only has one record, will implicitly update if they already exist.
Arguments
record- TheRecordto be inserted or updated.serial- Current serial number to be recorded against updates.
Return value
true if the value was inserted, false otherwise
Sourcepub fn upsert_mut(&mut self, record: Record, serial: u32) -> bool
pub fn upsert_mut(&mut self, record: Record, serial: u32) -> bool
Non-async version of upsert when behind a mutable reference.
Sourcepub fn add_zone_signing_key_mut(
&mut self,
signer: DnssecSigner,
) -> DnsSecResult<()>
Available on crate feature __dnssec only.
pub fn add_zone_signing_key_mut( &mut self, signer: DnssecSigner, ) -> DnsSecResult<()>
__dnssec only.Non-async method of add_zone_signing_key when behind a mutable reference
Sourcepub fn secure_zone_mut(&mut self) -> DnsSecResult<()>
Available on crate feature __dnssec only.
pub fn secure_zone_mut(&mut self) -> DnsSecResult<()>
__dnssec only.(Re)generates the nsec records, increments the serial number and signs the zone