pub struct ForwardZoneHandlerBuilder<P: ConnectionProvider> { /* private fields */ }Available on crate feature
resolver only.Expand description
A builder to construct a ForwardZoneHandler.
Created by ForwardZoneHandler::builder.
Implementations
Sourceimpl<P: ConnectionProvider> ForwardZoneHandlerBuilder<P>
impl<P: ConnectionProvider> ForwardZoneHandlerBuilder<P>
Sourcepub fn with_origin(self, origin: Name) -> Self
pub fn with_origin(self, origin: Name) -> Self
Set the origin of the zone handler.
Sourcepub fn with_trust_anchor(self, trust_anchor: Arc<TrustAnchors>) -> Self
Available on crate feature __dnssec only.
pub fn with_trust_anchor(self, trust_anchor: Arc<TrustAnchors>) -> Self
__dnssec only.Enables DNSSEC validation, and sets the DNSSEC trust anchors to be used by the forward zone handler.
This overrides the trust anchor path in the ResolverOpts.
Sourcepub fn options_mut(&mut self) -> &mut ResolverOpts
pub fn options_mut(&mut self) -> &mut ResolverOpts
Returns a mutable reference to the ResolverOpts.
Sourcepub fn with_domain(self, domain: Name) -> Self
pub fn with_domain(self, domain: Name) -> Self
Set the system domain name.
Sourcepub fn with_search(self, search: Vec<Name>) -> Self
pub fn with_search(self, search: Vec<Name>) -> Self
Set the search domains.
Sourcepub fn build(self) -> Result<ForwardZoneHandler<P>, String>
pub fn build(self) -> Result<ForwardZoneHandler<P>, String>
Construct the zone handler.