Available on crate feature
sqlite only.Expand description
All zone persistence related types
Structs
- Journal
- The Journal is the audit log of all changes to a zone after initial creation.
- Journal
Iter - Returns an iterator over all items in a Journal
Enums
- Persistence
Error - The error kind for errors that get returned in the crate
Constants
- CURRENT_
VERSION - The current Journal version of the application