Module for Catalog of ZoneHandler zones which are responsible for storing RRSet records.
Structs
- Axfr
Records - A collection of
RecordSets for an AXFR. - Axfr
Records Iter - An iterator over all records in a zone, except the SOA record.
- Catalog
- Set of zones and zone handlers available to this server.
- Lookup
Options - Options from the client to include or exclude various records in the response.
- Message
Request - A Message which captures the data from an inbound request
- Message
Response - A
crate::proto::serialize::binary::BinEncodablemessage with borrowed data for Responses in the Server - Message
Response Builder - A builder for MessageResponses
- Nsec3
Query Info __dnssec - Information required to compute the NSEC3 records that should be sent for a query.
- Queries
- A set of Queries with the associated serialized data
- Zone
Transfer - A copy of all data in a zone.
Enums
- Auth
Lookup - The result of a lookup on a ZoneHandler
- Auth
Lookup Iter - An iterator over a ZoneHandler lookup
- Axfr
Policy - AxfrPolicy describes how to handle AXFR requests
- Lookup
Control Flow - Result of a Lookup in the Catalog and ZoneHandler
- Lookup
Error - A query could not be fulfilled
- Lookup
Records - The result of a lookup
- Lookup
Records Iter - Iterator over lookup records
- Zone
Type - The type of zone stored in a Catalog
Traits
- Dnssec
Zone Handler - Extension to ZoneHandler to allow for DNSSEC features
- Update
Request - A type which represents an MessageRequest for dynamic Update.
- Zone
Handler - ZoneHandler implementations can be used with a
Catalog