pub struct MessageRequest {
pub metadata: Metadata,
pub queries: Queries,
pub answers: Vec<Record>,
pub authorities: Vec<Record>,
pub additionals: Vec<Record>,
pub signature: Option<Box<Record<TSIG>>>,
pub edns: Option<Edns>,
}Expand description
A Message which captures the data from an inbound request
Fields
metadata: MetadataMetadata from the message header
queries: QueriesQuery name and other query parameters
answers: Vec<Record>Records which directly answer the query
Records with describe other authoritative servers
May optionally carry the SOA record for the authoritative data in the answer section.
additionals: Vec<Record>Records which may be helpful in using the records in the other sections
signature: Option<Box<Record<TSIG>>>TSIG signature for the message, if any
edns: Option<Edns>RFC 6891, EDNS(0) Extensions, April 2013
6.1.1. Basic Elements
An OPT pseudo-RR (sometimes called a meta-RR) MAY be added to the
additional data section of a request.
The OPT RR has RR type 41.
If an OPT record is present in a received request, compliant
responders MUST include an OPT record in their respective responses.
An OPT record does not carry any DNS data. It is used only to
contain control information pertaining to the question-and-answer
sequence of a specific transaction. OPT RRs MUST NOT be cached,
forwarded, or stored in or loaded from Zone Files.
The OPT RR MAY be placed anywhere within the additional data section.
When an OPT RR is included within any DNS message, it MUST be the
only OPT RR in that message. If a query message with more than one
OPT RR is received, a FORMERR (RCODE=1) MUST be returned. The
placement flexibility for the OPT RR does not override the need for
the TSIG or SIG(0) RRs to be the last in the additional section
whenever they are present.Return value
Optionally returns a reference to EDNS OPT pseudo-RR
Implementations
Sourceimpl MessageRequest
impl MessageRequest
Sourcepub fn mock(metadata: Metadata, query: impl Into<LowerQuery>) -> Self
Available on crate features testing only.
pub fn mock(metadata: Metadata, query: impl Into<LowerQuery>) -> Self
testing only.Construct a mock MessageRequest for testing purposes
The unspecified fields are left empty.
Sourcepub fn max_payload(&self) -> u16
pub fn max_payload(&self) -> u16
Return value
the max payload value as it’s defined in the EDNS OPT pseudo-RR.